# server
workspace_id = 'wsp51aee96517063914'
# core 1
core_id_1 = 'cre51aeeb329c8d730d'
view_id_1 = 'viw51af07c50a0969e0'
table_id_1 = 'tbl51aeee11660d81c8'
column_id_1 = 'col51afae2e078653a5'
column_id_2 = 'colb59fa647b383c5a9'
column_name_1 = 'col_name1'
view_name_1 = 'viewname'
row_id_1 = 'row51af93a17a8bfe75'
core_name_1 = 'test_pysdk'
column_name_2 = 'col_name2'

# # local
# workspace_id = 'wspb59fa62a6d86ef67'
# # core 1
# core_id_1 = 'creb59fa62ae487268c'
# view_id_1 = 'viwb59fa62ee20e8fd9'
# table_id_1 = 'tblb59fa62b878b5fbf'
# column_id_1 = 'colb59fa646678b1f7a'
# column_id_2 = 'colb59fa647b383c5a9'
# column_name_1 = 'col_name1'
# column_name_2 = 'col_name2'
# view_name_1 = 'viewname'
# row_id_1 = 'rowb59fa6429886a435'
# core_name_1 = 'test_pysdk'

sleep_number = 5
sleep_time = 0.1
create_sleep_time = 0.2
